@@ -22,25 +22,11 @@
 #' df %>%
 #'   filter(b <= mean(b), .by = c)
 filter <- function(.df, ..., .by = NULL) {
-  .df <- .df_as_tidytable(.df)
-
-  if (is_ungrouped(.df)) {
-    tt_filter(.df, ..., .by = {{ .by }})
-  } else {
-    .by <- group_vars(.df)
-    tt_filter(.df, ..., .by = any_of(.by))
-  }
+  UseMethod("filter")
 }
 
 #' @export
-#' @keywords internal
-#' @inherit filter
-filter. <- function(.df, ..., .by = NULL) {
-  deprecate_dot_fun()
-  filter(.df, ..., .by = {{ .by }})
-}
-
-tt_filter <- function(.df, ..., .by = NULL) {
+filter.tidytable <- function(.df, ..., .by = NULL) {
   .by <- enquo(.by)
 
   dots <- enquos(...)
@@ -61,6 +47,20 @@ tt_filter <- function(.df, ..., .by = NULL) {
   eval_tidy(dt_expr, .df, dt_env)
 }
 
+#' @export
+filter.grouped_tt <- function(.df, ..., .by = NULL) {
+  .by <- group_vars(.df)
+  out <- ungroup(.df)
+  out <- filter(out, ..., .by = any_of(.by))
+  group_by(out, any_of(.by))
+}
+
+#' @export
+filter.data.frame <- function(.df, ..., .by = NULL) {
+  .df <- as_tidytable(.df)
+  filter(.df, ..., .by = {{ .by }})
+}
+
 check_filter <- function(dots) {
   .is_named <- have_name(dots)
 
