@@ -16,18 +16,6 @@ test_that("unnesting works with nested data.table", {
   expect_equal(unnest_df$a, start_df$a)
 })
 
-test_that("unnest. works", {
-  nest_df <- start_df %>%
-    nest_by(c, d)
-
-  unnest_df <- nest_df %>%
-    unnest.(data) %>%
-    suppressWarnings()
-
-  expect_named(unnest_df, c("c","d","a","b"))
-  expect_equal(unnest_df$a, start_df$a)
-})
-
 test_that("names_sep works", {
   nest_df <- start_df %>%
     nest_by(c, d)
@@ -144,13 +132,13 @@ test_that("works when the only column is a list column", {
   expect_equal(result_df$x, rep(1:3, 3))
 })
 
-test_that("keep_empty", {
+test_that("keep_empty works with NULL and length 0 vectors, #783", {
   nest_df <- tidytable(x = 1, y = 2)
 
   test_df <- tidytable(
     groups = c("a", "b", "c"),
     df_list = list(NULL, nest_df, nest_df),
-    vecs = list(NULL, 1, 2)
+    vecs = list(double(), 1, 2)
 
   )
 
